"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadConfigFromBundledFile = exports.sleep = exports.isBoolean = exports.isNumber = exports.isRegExp = exports.isArray = exports.isFunction = exports.is = void 0;
const path_1 = __importDefault(require("path"));
const toString = Object.prototype.toString;
function is(val, type) {
    return toString.call(val) === `[object ${type}]`;
}
exports.is = is;
function isFunction(val) {
    return is(val, 'Function');
}
exports.isFunction = isFunction;
function isArray(val) {
    return val && Array.isArray(val);
}
exports.isArray = isArray;
function isRegExp(val) {
    return is(val, 'RegExp');
}
exports.isRegExp = isRegExp;
function isNumber(val) {
    return is(val, 'Number');
}
exports.isNumber = isNumber;
function isBoolean(val) {
    return is(val, 'Boolean');
}
exports.isBoolean = isBoolean;
function sleep(time) {
    return new Promise((resolve) => {
        setTimeout(() => {
            resolve('');
        }, time);
    });
}
exports.sleep = sleep;
async function loadConfigFromBundledFile(fileName, bundledCode) {
    const extension = path_1.default.extname(fileName);
    const defaultLoader = require.extensions[extension];
    require.extensions[extension] = (module, filename) => {
        if (filename === fileName) {
            module._compile(bundledCode, filename);
        }
        else {
            defaultLoader(module, filename);
        }
    };
    delete require.cache[fileName];
    const raw = require(fileName);
    const config = raw.__esModule ? raw.default : raw;
    require.extensions[extension] = defaultLoader;
    return config;
}
exports.loadConfigFromBundledFile = loadConfigFromBundledFile;
